@@ -12,6 +12,7 @@ except:
     pass
 import youtubeservice
 import cutetubewindows
+from cutetubeconfig import *
 import os
 from Ui_addtoplaylistdialog import Ui_AddToPlaylistDialog
 from Ui_newplaylistdialog import Ui_NewPlaylistDialog
@@ -459,8 +460,6 @@ class SearchDialog(QDialog, Ui_searchDialog):
     """
     Dialog enabling the user to search YouTube videos.
     """
-    searchOrder = 0
-    recentSearches = QStringList()
     def __init__(self, parent = None,  username = None):
         """
         Constructor
@@ -489,11 +488,11 @@ class SearchDialog(QDialog, Ui_searchDialog):
         self.searchOrderSelector = QMaemo5ListPickSelector()
         self.searchOrderSelector.setModel(self.searchOrderModel)
         self.searchOrderButton.setPickSelector(self.searchOrderSelector)
-        self.searchOrderSelector.setCurrentIndex(SearchDialog.searchOrder)
+        self.searchOrderSelector.setCurrentIndex(SearchSettings.searchOrder)
         self.recentSearchesButton = QMaemo5ValueButton("Recent Searches", self)
         self.recentSearchesButton.setValueLayout(QMaemo5ValueButton.ValueUnderTextCentered)
         self.recentSearchesModel = QStandardItemModel(0, 1)
-        for searchString in SearchDialog.recentSearches:
+        for searchString in SearchSettings.recentSearches:
             item = QStandardItem(searchString)
             item.setEditable(False)
             item.setTextAlignment(Qt.AlignCenter)
@@ -533,15 +532,15 @@ class SearchDialog(QDialog, Ui_searchDialog):
         """
         Carries out the search.
         """
-        SearchDialog.searchOrder = self.searchOrderSelector.currentIndex()
+        SearchSettings.searchOrder = self.searchOrderSelector.currentIndex()
         searchString = unicode(self.lineEdit.text())
         searchDict = {"Date published": "published", "Relevance": "relevance", "View count": "viewCount", "Rating": "rating"}
         searchOrder = searchDict.get(unicode(self.searchOrderButton.valueText()))
-        if searchString in SearchDialog.recentSearches:
-            SearchDialog.recentSearches.removeAll(searchString)
-        if SearchDialog.recentSearches.count() > 30:
-            SearchDialog.removeAt(30)
-        SearchDialog.recentSearches.prepend(searchString)
+        if searchString in SearchSettings.recentSearches:
+            SearchSettings.recentSearches.removeAll(searchString)
+        if SearchSettings.recentSearches.count() > 30:
+            SearchSettings.recentSearches.removeAt(30)
+        SearchSettings.recentSearches.prepend(searchString)
         searchWindow = cutetubewindows.SearchResultsWindow(self, searchString, searchOrder, self.username)
         
     
@@ -568,21 +567,19 @@ class SettingsDialog(QDialog):
         downloadsLabel.setStyleSheet("color: rgb(120, 120, 120)")
         self.accountButton = QMaemo5ValueButton("Default account", self)
         self.accountButton.setValueLayout(QMaemo5ValueButton.ValueUnderText)
-        self.mediaPlayerButton = QMaemo5ValueButton("Default media player", self)
-        self.mediaPlayerButton.setValueLayout(QMaemo5ValueButton.ValueUnderText)
         self.playbackFormatButton = QMaemo5ValueButton("Video playback quality", self)
         self.playbackFormatButton.setValueLayout(QMaemo5ValueButton.ValueUnderText)
         self.downloadFolderButton = QMaemo5ValueButton("Download location", self)
         self.downloadFolderButton.setValueLayout(QMaemo5ValueButton.ValueUnderText)
-        self.downloadFolderButton.setValueText(youtubeservice.YouTubeVideoDownloader.downloadFolder)
+        self.downloadFolderButton.setValueText(VideoDownloadSettings.downloadFolder)
         self.downloadFormatButton = QMaemo5ValueButton("Video download quality", self)
         self.downloadFormatButton.setValueLayout(QMaemo5ValueButton.ValueUnderText)
         self.downloadStatusCheckBox = QCheckBox("Start downloads immediately",  self)
         self.downloadStatusCheckBox.setVisible(True)
-        if youtubeservice.YouTubeVideoDownloader.defaultTaskStatus == "queued":
+        if VideoDownloadSettings.defaultTaskStatus == "queued":
             self.downloadStatusCheckBox.setChecked(True)
         self.accountModel = QStandardItemModel(0, 1)
-        for account in youtubeservice.YouTubeDataService.userDict.iterkeys():
+        for account in YouTubeAPISettings.userDict.iterkeys():
             item = QStandardItem(account)
             item.setEditable(False)
             item.setTextAlignment(Qt.AlignCenter)
@@ -590,23 +587,7 @@ class SettingsDialog(QDialog):
         self.accountSelector = QMaemo5ListPickSelector()
         self.accountSelector.setModel(self.accountModel)
         self.accountButton.setPickSelector(self.accountSelector)
-        self.accountButton.setValueText(youtubeservice.YouTubeDataService.defaultUser)
-        self.mediaPlayerModel = QStandardItemModel(0, 1)
-        mediaPlayers = {"Media Player": "/usr/bin/mediaplayer", "KMPlayer": "/opt/kmplayer/bin/kmplayer", "MPlayer": "/usr/bin/mplayer"}
-        item = QStandardItem("cuteTube Player")
-        item.setEditable(False)
-        item.setTextAlignment(Qt.AlignCenter)
-        self.mediaPlayerModel.appendRow(item)
-        for mediaPlayer in mediaPlayers.iterkeys():
-            if os.path.exists(mediaPlayers.get(mediaPlayer)):
-                item = QStandardItem(mediaPlayer)
-                item.setEditable(False)
-                item.setTextAlignment(Qt.AlignCenter)
-                self.mediaPlayerModel.appendRow(item)
-        self.mediaPlayerSelector = QMaemo5ListPickSelector()
-        self.mediaPlayerSelector.setModel(self.mediaPlayerModel)
-        self.mediaPlayerButton.setPickSelector(self.mediaPlayerSelector)
-        self.mediaPlayerButton.setValueText(youtubeservice.YouTubeVideoPlayer.mediaPlayer)
+        self.accountButton.setValueText(YouTubeAPISettings.defaultUser)
         self.playbackFormatModel = QStandardItemModel(0,  1)
         for format in ("Mobile", "480x270"):
             item = QStandardItem(format)
@@ -616,10 +597,10 @@ class SettingsDialog(QDialog):
         self.playbackFormatSelector = QMaemo5ListPickSelector()
         self.playbackFormatSelector.setModel(self.playbackFormatModel)
         self.playbackFormatButton.setPickSelector(self.playbackFormatSelector)
-        playbackFormat = youtubeservice.YouTubeVideoPlayer.playbackFormat
-        self.playbackFormatSelector.setCurrentIndex(youtubeservice.YouTubeVideoPlayer.formatList.index(playbackFormat))
+        playbackFormat = VideoPlaybackSettings.playbackFormat
+        self.playbackFormatSelector.setCurrentIndex(VideoPlaybackSettings.formatList.index(playbackFormat))
         self.downloadFormatModel = QStandardItemModel(0,  1)
-        for format in ("Mobile", "480x270", "360p", "480p", "720p"):
+        for format in ("Mobile", "480x270"):
             item = QStandardItem(format)
             item.setEditable(False)
             item.setTextAlignment(Qt.AlignCenter)
@@ -627,8 +608,8 @@ class SettingsDialog(QDialog):
         self.downloadFormatSelector = QMaemo5ListPickSelector()
         self.downloadFormatSelector.setModel(self.downloadFormatModel)
         self.downloadFormatButton.setPickSelector(self.downloadFormatSelector)
-        downloadFormat = youtubeservice.YouTubeVideoDownloader.downloadFormat
-        self.downloadFormatSelector.setCurrentIndex(youtubeservice.YouTubeVideoPlayer.formatList.index(downloadFormat))
+        downloadFormat = VideoDownloadSettings.downloadFormat
+        self.downloadFormatSelector.setCurrentIndex(VideoDownloadSettings.formatList.index(downloadFormat))
         self.searchesLabel = QLabel("Youtube Searches")
         self.searchesLabel.setStyleSheet("color: rgb(120, 120, 120)")
         self.clearSearchesButton = QPushButton("Clear recent searches", self)
@@ -641,7 +622,6 @@ class SettingsDialog(QDialog):
         vBox.addWidget(accountLabel)
         vBox.addWidget(self.accountButton)
         vBox.addWidget(playerLabel)
-        vBox.addWidget(self.mediaPlayerButton)
         vBox.addWidget(self.playbackFormatButton)
         vBox.addWidget(downloadsLabel)
         vBox.addWidget(self.downloadFolderButton)
@@ -667,12 +647,12 @@ class SettingsDialog(QDialog):
         screenGeometry = QApplication.desktop().screenGeometry()
         if screenGeometry.height() > screenGeometry.width():
             self.resize(480,  720)
-            for button in (self.accountButton, self.mediaPlayerButton, self.playbackFormatButton, self.downloadFolderButton, self.downloadFormatButton, self.downloadStatusCheckBox, self.clearSearchesButton):
+            for button in (self.accountButton, self.playbackFormatButton, self.downloadFolderButton, self.downloadFormatButton, self.downloadStatusCheckBox, self.clearSearchesButton):
                 button.setFixedWidth(420)
             self.saveButton.setGeometry(QRect(10,  620,  460,  70))
         else:
             self.resize(800,  400)
-            for button in (self.accountButton, self.mediaPlayerButton, self.playbackFormatButton, self.downloadFolderButton, self.downloadFormatButton, self.downloadStatusCheckBox, self.clearSearchesButton):
+            for button in (self.accountButton, self.playbackFormatButton, self.downloadFolderButton, self.downloadFormatButton, self.downloadStatusCheckBox, self.clearSearchesButton):
                 button.setFixedWidth(580)
             self.saveButton.setGeometry(QRect(640,  300,  150,  70))
         
@@ -687,7 +667,7 @@ class SettingsDialog(QDialog):
         Clears the user's recent searches.
         """
         try:
-            SearchDialog.recentSearches.clear()
+            SearchSettings.recentSearches.clear()
             QMaemo5InformationBox.information(self, "Your recent searches have been cleared")
         except:
             QMaemo5InformationBox.information(self, "Unable to clear your recent searches")
@@ -698,19 +678,17 @@ class SettingsDialog(QDialog):
         Saves the settings chosen by the user.
         """
         account = unicode(self.accountButton.valueText())
-        mediaPlayer = unicode(self.mediaPlayerButton.valueText())
         downloadFolder = unicode(self.downloadFolderButton.valueText())
         playbackFormat = self.playbackFormatSelector.currentIndex()
         downloadFormat = self.downloadFormatSelector.currentIndex()
-        youtubeservice.YouTubeDataService.defaultUser = account
-        youtubeservice.YouTubeVideoPlayer.mediaPlayer = mediaPlayer
-        youtubeservice.YouTubeVideoPlayer.playbackFormat = youtubeservice.YouTubeVideoPlayer.formatList[playbackFormat]
-        youtubeservice.YouTubeVideoDownloader.downloadFormat = youtubeservice.YouTubeVideoPlayer.formatList[downloadFormat]
-        youtubeservice.YouTubeVideoDownloader.downloadFolder = downloadFolder
+        YouTubeAPISettings.defaultUser = account
+        VideoPlaybackSettings.playbackFormat = VideoPlaybackSettings.formatList[playbackFormat]
+        VideoDownloadSettings.downloadFormat = VideoDownloadSettings.formatList[downloadFormat]
+        VideoDownloadSettings.downloadFolder = downloadFolder
         if self.downloadStatusCheckBox.isChecked():
-            youtubeservice.YouTubeVideoDownloader.defaultTaskStatus = "queued"
+            VideoDownloadSettings.defaultTaskStatus = "queued"
         else:
-            youtubeservice.YouTubeVideoDownloader.defaultTaskStatus = "paused"
+            VideoDownloadSettings.defaultTaskStatus = "paused"
         QMaemo5InformationBox.information(self,  "Your settings have been saved")
         self.close()
         
@@ -777,7 +755,7 @@ class SwitchAccountDialog(QDialog, Ui_SwitchAccountDialog):
         QDialog.__init__(self, parent)
         self.setupUi(self)
         self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-        for username in youtubeservice.YouTubeDataService.userDict.iterkeys():
+        for username in YouTubeAPISettings.userDict.iterkeys():
             item = QListWidgetItem(username)
             item.setTextAlignment(Qt.AlignCenter)
             self.listWidget.addItem(item)
@@ -848,14 +826,14 @@ class AddAccountDialog(QDialog, Ui_AddAccountDialog):
         email = self.emailEdit.text()
         password = self.passwordEdit.text()
         try:
-            if self.defaultCheckBox.isChecked() or youtubeservice.YouTubeDataService.userDict == {}:
-                youtubeservice.YouTubeDataService.defaultUser = username
-            youtubeservice.YouTubeDataService.userDict.update({username: (email, password)})
+            if self.defaultCheckBox.isChecked() or YouTubeAPISettings.userDict == {}:
+                YouTubeAPISettings.defaultUser = username
+            YouTubeAPISettings.userDict.update({username: (email, password)})
             youtubeservice.YouTubeDataService.youtubeLogin(username)
             QMaemo5InformationBox.information(self, "Account added. You are now signed in to YouTube as \'%s\'" % username)
             self.accept()
         except:
-            del(youtubeservice.YouTubeDataService.userDict[username])
+            del(YouTubeAPISettings.userDict[username])
             QMaemo5InformationBox.information(self, "Unable to sign in to your YouTube account. Please check your account details")
 
 class ManageAccountsDialog(QDialog, Ui_ManageAccountsDialog):
@@ -872,7 +850,7 @@ class ManageAccountsDialog(QDialog, Ui_ManageAccountsDialog):
         self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
         self.orientationChanged()
         self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
-        for username in youtubeservice.YouTubeDataService.userDict.iterkeys():
+        for username in YouTubeAPISettings.userDict.iterkeys():
             item = QListWidgetItem(username)
             item.setTextAlignment(Qt.AlignHCenter | Qt.AlignVCenter)
             self.listWidget.addItem(item)
@@ -940,7 +918,7 @@ class ManageAccountsDialog(QDialog, Ui_ManageAccountsDialog):
         Deletes the chosen account.
         """
         try:
-            del youtubeservice.YouTubeDataService.userDict[self.username]
+            del(YouTubeAPISettings.userDict[self.username])
             QMaemo5InformationBox.information(self, "You have deleted the account \'%s\'" % self.username)
         except:
             QMaemo5InformationBox.information(self, "Unable to delete the account")
@@ -960,13 +938,13 @@ class EditAccountDialog(QDialog, Ui_EditAccountDialog):
         self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
         self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
         self.usernameEdit.setText(username)
-        loginInfo = youtubeservice.YouTubeDataService.userDict.get(username)
+        loginInfo = YouTubeAPISettings.userDict.get(username)
         email = loginInfo[0]
         password = loginInfo[1]
         self.emailEdit.setText(email)
         self.passwordEdit.setText(password)
         self.passwordEdit.setEchoMode(QLineEdit.Password)
-        if youtubeservice.YouTubeDataService.defaultUser == username:
+        if YouTubeAPISettings.defaultUser == username:
             self.defaultCheckBox.setChecked(True)
         self.show()
 
@@ -1009,11 +987,11 @@ class EditAccountDialog(QDialog, Ui_EditAccountDialog):
         email = self.emailEdit.text()
         password = self.passwordEdit.text()
         try:
-            youtubeservice.YouTubeDataService.userDict.update({username: (email, password)})
+            YouTubeAPISettings.update({username: (email, password)})
             currentUser = youtubeservice.YouTubeDataService.currentUser
             youtubeservice.YouTubeDataService.youtubeLogin(username)
             if self.defaultCheckBox.isChecked():
-                youtubeservice.YouTubeDataService.defaultUser = username
+                YouTubeAPISettings.defaultUser = username
             QMaemo5InformationBox.information(self, "YouTube account details for \'%s\' successfully verified" % username)
             youtubeservice.YouTubeDataService.youtubeLogin(currentUser)            
         except:
@@ -1066,5 +1044,5 @@ class NoAccountFoundDialog(QDialog,  Ui_NoAccountFoundDialog):
         Sets the raiseNoAccountFoundDialog variable 
         in YouTubeDataService to False.
         """
-        youtubeservice.YouTubeDataService.raiseNoAccountFoundDialog = False
+        YouTubeAPISettings.raiseNoAccountFoundDialog = False
             
