@@ -16,7 +16,8 @@ import myaccountwindow
 import cutetubedialogs
 import aboutdialog
 import cutetubewindows
-import youtubeservice
+from youtubeservice import YouTubeDataService, YouTubeVideoDownloader
+from cutetubeconfig import *
 
 class HomeWindow(QMainWindow, Ui_HomeWindow):
     """
@@ -45,7 +46,7 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
             self.connect(button,  SIGNAL("pressed()"), self.changeButtonStyleSheet)
             self.connect(button,  SIGNAL("released()"), self.changeButtonStyleSheet)
         self.searchDialogRaised = False
-        taskQueueLength = len(youtubeservice.YouTubeVideoDownloader.taskQueue)
+        taskQueueLength = len(YouTubeVideoDownloader.taskQueue)
         if taskQueueLength > 0:
             self.actionDownloads.setVisible(True)
             self.actionDownloads.setText("Downloads (%s videos)" % unicode(taskQueueLength))
@@ -72,17 +73,17 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         Attempt to sign in using the default account details.
         """
         try:
-            if youtubeservice.YouTubeDataService.userDict == {}:
-                if youtubeservice.YouTubeDataService.raiseNoAccountFoundDialog:
+            if YouTubeAPISettings.userDict == {}:
+                if YouTubeAPISettings.raiseNoAccountFoundDialog:
                     noAccountFoundDialog = cutetubedialogs.NoAccountFoundDialog(self)
             else:
-                username = youtubeservice.YouTubeDataService.defaultUser
-                youtubeservice.YouTubeDataService.youtubeLogin(username)
+                username = YouTubeAPISettings.defaultUser
+                YouTubeDataService.youtubeLogin(username)
                 QMaemo5InformationBox.information(self, "You are signed in to YouTube as \'%s\'" % username)
         except:
             try:
-                username = youtubeservice.YouTubeDataService.userDict.keys()[0]
-                youtubeservice.YouTubeDataService.youtubeLogin(username)
+                username = YouTubeAPISettings.userDict.keys()[0]
+                YouTubeDataService.youtubeLogin(username)
                 QMaemo5InformationBox.information(self, "You are signed in to YouTube as \'%s\'" % username)
             except:
                 QMaemo5InformationBox.information(self, "Unable to sign in to your YouTube account")
@@ -108,38 +109,34 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         Restores the application settings.
         """
         settings = QSettings()
-        youtubeservice.YouTubeDataService.userDict = settings.value("userDict",  {}).toPyObject()
-        youtubeservice.YouTubeDataService.defaultUser = settings.value("defaultUser",  "").toString()
-        youtubeservice.YouTubeDataService.raiseNoAccountFoundDialog = settings.value("noAccountDialog",  True).toBool()
-        youtubeservice.YouTubeVideoPlayer.mediaPlayer = settings.value("mediaPlayer",  "cuteTube Player").toString()
-        youtubeservice.YouTubeVideoDownloader.downloadFolder = settings.value("downloadFolder",  "/home/user/MyDocs/.videos").toString()
-        youtubeservice.YouTubeVideoDownloader.defaultTaskStatus = settings.value("downloadStatus",  "paused").toString()
-        format = youtubeservice.YouTubeVideoPlayer.playbackFormat
-        if youtubeservice.YouTubeVideoPlayer.playbackFormat in ("17", "18"): # Temporary kludge to ensure playback resolution is set to <= 480x270
-            youtubeservice.YouTubeVideoPlayer.playbackFormat = settings.value("playbackFormat",  "18").toPyObject()
-        youtubeservice.YouTubeVideoDownloader.downloadFormat = settings.value("downloadFormat",  "18").toPyObject()
-        cutetubedialogs.SearchDialog.searchOrder = settings.value("searchOrder",  0).toInt()[0]
-        cutetubedialogs.SearchDialog.recentSearches = settings.value("recentSearches", QStringList()).toStringList()
+        YouTubeAPISettings.userDict = settings.value("userDict",  {}).toPyObject()
+        YouTubeAPISettings.defaultUser = settings.value("defaultUser",  "").toString()
+        YouTubeAPISettings.raiseNoAccountFoundDialog = settings.value("noAccountDialog",  True).toBool()
+        VideoPlaybackSettings.playbackFormat = settings.value("playbackFormat",  "18").toPyObject()
+        VideoDownloadSettings.downloadFolder = settings.value("downloadFolder",  "/home/user/MyDocs/.videos").toString()
+        VideoDownloadSettings.defaultTaskStatus = settings.value("downloadStatus",  "paused").toString()
+        if settings.value("downloadFormat",  "18").toPyObject() in ("17", "18"):
+            VideoDownloadSettings.downloadFormat = settings.value("downloadFormat",  "18").toPyObject()
+        SearchSettings.searchOrder = settings.value("searchOrder",  0).toInt()[0]
+        SearchSettings.recentSearches = settings.value("recentSearches", QStringList()).toStringList()
         
     def closeEvent(self,  event):
         """
         Saves the application settings.
         """
         settings = QSettings()
-        userDict = QVariant(youtubeservice.YouTubeDataService.userDict)
-        defaultUser = QVariant(youtubeservice.YouTubeDataService.defaultUser)
-        noAccountDialog = QVariant(youtubeservice.YouTubeDataService.raiseNoAccountFoundDialog)
-        mediaPlayer = QVariant(youtubeservice.YouTubeVideoPlayer.mediaPlayer)
-        downloadFolder = QVariant(youtubeservice.YouTubeVideoDownloader.downloadFolder)
-        downloadStatus = QVariant(youtubeservice.YouTubeVideoDownloader.defaultTaskStatus)
-        playbackFormat = QVariant(youtubeservice.YouTubeVideoPlayer.playbackFormat)
-        downloadFormat = QVariant(youtubeservice.YouTubeVideoDownloader.downloadFormat)
-        searchOrder = QVariant(cutetubedialogs.SearchDialog.searchOrder)
-        recentSearches = QVariant(cutetubedialogs.SearchDialog.recentSearches)
+        userDict = QVariant(YouTubeAPISettings.userDict)
+        defaultUser = QVariant(YouTubeAPISettings.defaultUser)
+        noAccountDialog = QVariant(YouTubeAPISettings.raiseNoAccountFoundDialog)
+        playbackFormat = QVariant(VideoPlaybackSettings.playbackFormat)        
+        downloadFolder = QVariant(VideoDownloadSettings.downloadFolder)
+        downloadStatus = QVariant(VideoDownloadSettings.defaultTaskStatus)
+        downloadFormat = QVariant(VideoDownloadSettings.downloadFormat)
+        searchOrder = QVariant(SearchSettings.searchOrder)
+        recentSearches = QVariant(SearchSettings.recentSearches)
         settings.setValue("userDict", userDict)
         settings.setValue("defaultUser", defaultUser)
         settings.setValue("noAccountDialog", noAccountDialog)
-        settings.setValue("mediaPlayer", mediaPlayer)
         settings.setValue("downloadFolder", downloadFolder)
         settings.setValue("downloadStatus", downloadStatus)
         settings.setValue("playbackFormat", playbackFormat)
@@ -209,7 +206,7 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         """
         Creates a MyAccounrtWindow
         """
-        if youtubeservice.YouTubeDataService.currentUser == "":
+        if YouTubeDataService.currentUser == "":
             QMaemo5InformationBox.information(self, "You are not signed in to YouTube")
         else:
             myAccountWindow = myaccountwindow.MyAccountWindow(self)
