@@ -16,7 +16,7 @@ import cutetubedialogs
 import cutetubewindows
 import youtubeservice
 import customwidgets
-import videoplaybackwindow
+from videoplaybackwindow import VideoPlaybackWindow
 
 class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
     """
@@ -143,12 +143,7 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         """
         videoTitle = self.video.title.text
         try:
-            if youtubeservice.YouTubeVideoPlayer.mediaPlayer == "cuteTube Player":
-                videoPlaybackWindow = videoplaybackwindow.VideoPlaybackWindow(self, video = self.video)
-            else:
-                self.ytPlayer = youtubeservice.YouTubeVideoPlayer(self, self.video)
-                self.ytPlayer.start()
-                QMaemo5InformationBox.information(self, "Playing \'%s\'" % unicode(videoTitle, "utf-8"))
+            videoPlaybackWindow = VideoPlaybackWindow(self, video = self.video)
         except:
             QMaemo5InformationBox.information(self, "Unable to play video")
 
@@ -186,9 +181,9 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         """
         videoTitle = self.video.media.title.text
         try:
-            youtubeservice.YouTubeVideoPlayer.playlist.append(self.video)
-            QMaemo5InformationBox.information(self, "\'%s\' added to playback queue" % unicode(videoTitle, "utf-8"))
-            self.emit(SIGNAL("queueChanged(int)"), len(youtubeservice.YouTubeVideoPlayer.playlist))
+            youtubeservice.YouTubeQueueFeed.playlist.append(self.video)
+            self.emit(SIGNAL("queueChanged(int)"), len(youtubeservice.YouTubeQueueFeed.playlist))
+            QMaemo5InformationBox.information(self, "\'%s\' added to playback queue" % unicode(videoTitle, "utf-8"))            
         except:
             QMaemo5InformationBox.information(self, "Unable to add video to playback queue")
        
