@@ -19,16 +19,14 @@ import os
 import shutil
 import gdata.youtube.service
 import gdata.service
+from cutetubeconfig import *
 
 class YouTubeDataService(object):
     """
     Class providing access to the YouTube API.
     """
-    # Static variables
-    userDict = {}
-    defaultUser = ""
+    #Static variables
     currentUser = ""
-    raiseNoAccountFoundDialog = True
     ytService = gdata.youtube.service.YouTubeService()
     ytService.email = ""
     ytService.password = ""
@@ -49,15 +47,15 @@ class YouTubeDataService(object):
         """
         Logs in to the user's chosen YouTube account.
         """       
-        YouTubeDataService.ytService.email = unicode(YouTubeDataService.userDict[username][0], "utf-8")
-        YouTubeDataService.ytService.password = unicode(YouTubeDataService.userDict[username][1], "utf-8")
+        YouTubeDataService.ytService.email = unicode(YouTubeAPISettings.userDict[username][0], "utf-8")
+        YouTubeDataService.ytService.password = unicode(YouTubeAPISettings.userDict[username][1], "utf-8")
         try:
             YouTubeDataService.ytService.ProgrammaticLogin()
             YouTubeDataService.currentUser = username
         except:
             # Some users have reported authentication issues. Using the username in place of the email address may work.
             YouTubeDataService.ytService.email = unicode(username, "utf-8")
-            YouTubeDataService.ytService.password = unicode(YouTubeDataService.userDict[username][1], "utf-8")
+            YouTubeDataService.ytService.password = unicode(YouTubeAPISettings.userDict[username][1], "utf-8")
             YouTubeDataService.ytService.ProgrammaticLogin()
             YouTubeDataService.currentUser = username
         
@@ -189,7 +187,7 @@ class YouTubeDataService(object):
             videoInfo = parse_qs(videoInfoWebpage)
             if 'token' in videoInfo:
                 videoToken = urllib.unquote_plus(videoInfo['token'][0])
-                formatList = ['22', '35', '34', '18', '17']
+                formatList = ['18', '17']
                 for format in formatList[formatList.index(videoFormat):]:
                     videoUrl = 'http://www.youtube.com/get_video?video_id=%s&t=%s&eurl=&el=&ps=&asv=&fmt=%s' % (videoId, videoToken,  format)
                     videoLength = urllib.urlopen(videoUrl).info()["Content-Length"]
@@ -245,6 +243,8 @@ class YouTubeQueueFeed(QThread):
     """
     Pulls the video feed from the YouTube server.
     """
+    #Static variables
+    playlist = []
 
     def __init__(self, parent):
         QThread.__init__(self, parent)
@@ -253,7 +253,7 @@ class YouTubeQueueFeed(QThread):
         """
         Retrieves and returns the video feed.
         """
-        for video in YouTubeVideoPlayer.playlist:
+        for video in YouTubeQueueFeed.playlist:
             try:
                 thumbnail = YouTubeDataService.getVideoThumbnail(video.media.thumbnail[3].url)
                 videoData = (video, thumbnail)
@@ -268,7 +268,6 @@ class YouTubeDownloadQueueFeed(QThread):
     """
     Pulls the video feed from the YouTube server.
     """
-
     def __init__(self, parent):
         QThread.__init__(self, parent)
     
@@ -352,59 +351,15 @@ class YouTubeCommentsFeed(QThread):
     def run(self):
         self.getVideoComments()
 
-class YouTubeVideoPlayer(QThread):
-    """
-    Provides YouTube video playback functions.
-    """
-    # Static variables
-    playlist = []
-    mediaPlayer = "cuteTube Player"
-    formatList = ["17", "18", "34", "35", "22"]
-    playbackFormat = "18"
-    playCommandDict = {"KMPlayer": "dbus-send --print-reply --dest=com.nokia.kmplayer /com/nokia/kmplayer com.nokia.kmplayer.mime_open string:\'%s\'", "MPlayer": "mplayer -fs \'%s\'", "Media Player": "dbus-send --print-reply --dest=com.nokia.mediaplayer /com/nokia/mediaplayer com.nokia.mediaplayer.mime_open string:\'%s\'"}
-    
-    def __init__(self, parent, video = None):
-        """
-        Constructor
-        """
-        QThread.__init__(self, parent)
-        self.video = video
-        
-    def createAndPlayPlaylist(self):
-        playlistFile = "%s/cutetube.m3u" % YouTubeVideoDownloader.downloadFolder
-        with open(playlistFile, "w") as file:
-            for video in YouTubeVideoPlayer.playlist:
-                videoUrl = YouTubeDataService.getVideoUrl(video)
-                file.write(unicode(videoUrl + "\n"))
-        playbackCommand = YouTubeVideoPlayer.playCommandDict.get(YouTubeVideoPlayer.mediaPlayer)
-        os.system(playbackCommand % playlistFile)
-
-    def playYouTubeVideo(self):
-        playbackCommand = YouTubeVideoPlayer.playCommandDict.get(unicode(YouTubeVideoPlayer.mediaPlayer))
-        filename = "%s/%s.mp4" % (YouTubeVideoDownloader.downloadFolder, re.sub('[<>:"/|?*\\\\]', "-", self.video.media.title.text).decode("utf-8"))
-        if os.path.exists(filename):
-            os.system(playbackCommand % filename.encode("utf-8"))
-        else:
-            videoUrl = YouTubeDataService.getVideoUrl(self.video,  YouTubeVideoPlayer.playbackFormat)
-            os.system(playbackCommand % videoUrl) 
-
-    def run(self):
-        self.playYouTubeVideo()
-
 class YouTubeVideoDownloader(object):
     """
     Manages download tasks in the download queue.
     """
     # Static variables
-    downloadFolder = "/home/user/MyDocs/.videos"
-    downloadFormat = "18"
     downloadQueue = []
     taskQueue = []
-    completedDownloads = []
     currentTask = None
     currentStatus = "inactive"
-    defaultTaskStatus = "queued"
-
 
     def __init__(self, parent = None):
         """
@@ -420,7 +375,7 @@ class YouTubeVideoDownloader(object):
         YouTubeVideoDownloader.downloadQueue.append(video)
         task = DownloadTask(video)
         YouTubeVideoDownloader.taskQueue.append(task)
-        if YouTubeVideoDownloader.currentStatus == "inactive" and YouTubeVideoDownloader.defaultTaskStatus == "queued":
+        if YouTubeVideoDownloader.currentStatus == "inactive" and VideoDownloadSettings.defaultTaskStatus == "queued":
             YouTubeVideoDownloader.run()
             
     @staticmethod
@@ -447,16 +402,6 @@ class YouTubeVideoDownloader(object):
         if YouTubeVideoDownloader.currentStatus == "inactive":
             YouTubeVideoDownloader.run()
             
-    @staticmethod
-    def moveCompletedTask():
-        """
-        Moves the completed task to the completedDownloads list.
-        """
-        completedTask = YouTubeVideoDownloader.currentTask
-        YouTubeVideoDownloader.taskQueue.remove(completedTask)
-        YouTubeVideoDownloader.downloadQueue.remove(completedTask)
-        YouTubeVideoDownloader.completedDownloads.insert(0, completedTask)
-            
     @staticmethod
     def clearTasks():
         """
@@ -502,14 +447,14 @@ class DownloadTask(QThread):
 
     def __init__(self, video):
         QThread.__init__(self,  parent = None)
-        self.status = YouTubeVideoDownloader.defaultTaskStatus
+        self.status = VideoDownloadSettings.defaultTaskStatus
         self.statusChanged = True
         self.video = video
         self.connect(self,  SIGNAL("finished()"),  YouTubeVideoDownloader.run)
 
         # Create the target filename
 
-        self.filename = "%s/%s.mp4" % (YouTubeVideoDownloader.downloadFolder, unicode(re.sub('[:/|\\\\]', "-", self.video.media.title.text), "utf-8"))
+        self.filename = "%s/%s.mp4" % (VideoDownloadSettings.downloadFolder, unicode(re.sub('[:/|\\\\]', "-", self.video.media.title.text), "utf-8"))
         self.tempname = self.filename + '.partial'
 
         self.totalSize = 0
@@ -582,7 +527,7 @@ class DownloadTask(QThread):
 
         try:
             # Resolve URL and start downloading the episode
-            url = YouTubeDataService.getVideoUrl(self.video,  YouTubeVideoDownloader.downloadFormat)
+            url = YouTubeDataService.getVideoUrl(self.video,  VideoDownloadSettings.downloadFormat)
             downloader =  DownloadURLOpener()
             headers, realUrl = downloader.retrieveResume(url, \
                     self.tempname, reporthook=self.statusUpdated)
